@@ -1,29 +1,26 @@
-import os
+"""
+Create a new django migration with support for fixing conflicts.
+"""
+
 import os
 import pathlib
-from importlib import import_module
 
 from django.apps import apps
 from django.conf import settings
-from django.core.management.base import (
-    CommandError,
-    no_translations,
-)
+from django.core.management.base import CommandError, no_translations
 from django.core.management.commands.makemigrations import Command as BaseCommand
 from django.db import DEFAULT_DB_ALIAS, connections, router
 from django.db.migrations.loader import MigrationLoader
 
-from migration_fixer.utils import run_command, fix_migration, fix_numbered_migration
+from migration_fixer.utils import fix_migration, fix_numbered_migration, run_command
 
 
 class Command(BaseCommand):
-    help = "Creates new migration(s) for apps."
-
     def add_arguments(self, parser):
         parser.add_argument(
             "--fix",
             action="store_true",
-            help="Fix django migrations using a diff of the default branch.",
+            help="Fix migrations conflicts.",
         )
         parser.add_argument(
             "-b",
@@ -53,7 +50,8 @@ class Command(BaseCommand):
                         raise CommandError(
                             self.style.ERROR(
                                 f"VCS is not yet setup. "
-                                f'Please run (git init) \n"{git_setup_output or git_setup_error}"'
+                                "Please run (git init) "
+                                f'\n"{git_setup_output or git_setup_error}"'
                             )
                         )
 
@@ -74,7 +72,10 @@ class Command(BaseCommand):
                     pull_command = (
                         "git pull"
                         if get_current_branch_output == self.default_branch
-                        else f"git fetch --depth=1 origin {self.default_branch}:{self.default_branch}"
+                        else (
+                            "git fetch --depth=1 origin "
+                            f"{self.default_branch}:{self.default_branch}"
+                        )
                     )
 
                     # Pull the last commit
@@ -133,11 +134,11 @@ class Command(BaseCommand):
                     # hard if there are any and they don't want to merge
                     conflicts = loader.detect_conflicts()
 
-                    app_labels = app_labels or [
+                    app_labels = app_labels or tuple(
                         app_label
                         for app_label in settings.INSTALLED_APPS
                         if app_label in conflicts
-                    ]
+                    )
 
                     for app_label in app_labels:
                         conflict = conflicts.get(app_label)
@@ -161,7 +162,8 @@ class Command(BaseCommand):
                             if not get_changed_files:
                                 raise CommandError(
                                     self.style.ERROR(
-                                        f"Error retrieving changed files on ({self.default_branch}): "
+                                        "Error retrieving changed files on "
+                                        f"({self.default_branch}): "
                                         f'"{get_changed_files_output or get_changed_files_error}"'
                                     )
                                 )
