@@ -1,16 +1,16 @@
 import abc
 from io import StringIO
-
-from six import with_metaclass
+from typing import Type
 
 from django.core.management import BaseCommand, call_command
 from django.test import TestCase
+from six import with_metaclass
 
 
 class BaseCommandTestCase(with_metaclass(abc.ABCMeta, TestCase)):
-    cmd_class = None
+    cmd_class: Type[BaseCommand]
     cmd_name = None
-    expected_output = None
+    expected_output: str
     base_kwargs = {"verbosity": 0}
 
     @classmethod
